@@ -27,8 +27,24 @@ const (
 	DocFilter
 )
 
+// documentType is the type of document.
 type documentType int
 
+// String returns the string representation of the document type.
+func (d documentType) String() string {
+	switch d {
+	case DocNormal:
+		return "normal"
+	case DocHelp:
+		return "help"
+	case DocLog:
+		return "log"
+	case DocFilter:
+		return "filter"
+	}
+	return "unknown"
+}
+
 // Document represents a document with various properties and methods for handling
 // file operations, caching, synchronization, and display settings.
 type Document struct {
@@ -79,8 +95,8 @@ type Document struct {
 	// columnWidths is a slice of column widths.
 	columnWidths []int
 
-	// status is the display status of the document.
-	general
+	// RunTimeSettings contains RunTimeSettings settings.
+	RunTimeSettings
 
 	// memoryLimit is the maximum chunk size.
 	memoryLimit int
@@ -230,26 +246,21 @@ type columnRange struct {
 // It returns a pointer to the Document and an error if the cache initialization fails.
 func NewDocument() (*Document, error) {
 	m := &Document{
-		documentType: DocNormal,
-		tickerDone:   make(chan struct{}),
-		general: general{
-			ColumnDelimiter: "",
-			TabWidth:        8,
-			MarkStyleWidth:  1,
-			Converter:       convEscaped,
-		},
-		ctlCh:        make(chan controlSpecifier),
-		memoryLimit:  100,
-		seekable:     true,
-		reopenable:   true,
-		store:        NewStore(),
-		lastSearchLN: -1,
+		documentType:    DocNormal,
+		tickerDone:      make(chan struct{}),
+		RunTimeSettings: NewRunTimeSettings(),
+		ctlCh:           make(chan controlSpecifier),
+		memoryLimit:     100,
+		seekable:        true,
+		reopenable:      true,
+		store:           NewStore(),
+		lastSearchLN:    -1,
 	}
 	if err := m.NewCache(); err != nil {
 		return nil, err
 	}
 	m.alignConv = newAlignConverter(m.ColumnWidth)
-	m.conv = m.converterType(m.general.Converter)
+	m.conv = m.converterType(m.RunTimeSettings.Converter)
 
 	m.cond = sync.NewCond(&sync.Mutex{})
 	return m, nil
@@ -618,6 +629,7 @@ func (m *Document) vHeaderWidth(lineC LineC) int {
 }
 
 // GetLine returns one line from buffer.
+//
 // Deprecated: Use [Document.LineString] instead.
 func (m *Document) GetLine(n int) string {
 	s, err := m.Line(n)
@@ -628,6 +640,7 @@ func (m *Document) GetLine(n int) string {
 }
 
 // LineString returns one line from buffer.
+//
 // Deprecated: Use [Document.LineStr] instead.
 func (m *Document) LineString(n int) string {
 	str, _ := m.LineStr(n)
